@@ -26,13 +26,13 @@ class LogMsg:
     level: LogLevel
     data: str
     function_run_record_id: str
-    time: datetime=field(default_factory=datetime.now)
+    time: datetime=field(default_factory=datetime.utcnow)
 
     def json_dict(self):
         return {
             "level": self.level.value,
             "data": self.data,
-            "time": self.time,
+            "time": self.time.strftime("%Y-%m-%dT%H:%M:%S.%fZ"),
             "tag_map": {
                 "function_run_record_id": self.function_run_record_id
             }
